@@ -3,7 +3,7 @@ ssplotM <- function(x, hidden.paths,
                    sortv, sort.channel, dist.method,
                    with.missing, missing.color,
                    title, title.n, cex.title, title.pos,
-                   withlegend, ncol.legend, 
+                   with.legend, ncol.legend, 
                    with.missing.legend,                         
                    legend.prop, cex.legend,
                    hidden.states.colors, hidden.states.labels,
